module Dummy;
use v6;

sub load_test () is exported {
  say "Module Dummy.pm was loaded"
};

1;
